@@ -186,6 +186,8 @@ func (c *LDAPController) SearchForUserGroupMembership(userDN string) ([]authenti
 			groups = append(groups, authenticationcallouts.UserGroupIDAdmin)
 		case c.settings.GroupMapping.SuperAdmin:
 			groups = append(groups, authenticationcallouts.UserGroupIDSuperAdmin)
+		case c.settings.GroupMapping.ReadOnly:
+			groups = append(groups, authenticationcallouts.UserGroupIDReadOnly)
 		case c.settings.MandatoryAllowGroup:
 			allowed = true
 		}
