@@ -550,6 +550,7 @@ func TestSearchForUserGroupMembershipMapping(t *testing.T) {
 		GroupMapping: internal.GroupMapping{
 			Admin:      "administrator",
 			SuperAdmin: "super-administrator",
+			ReadOnly:   "read-only",
 		},
 	}
 	controller := internal.NewLDAPController(settings, mock)
@@ -617,6 +618,30 @@ func TestSearchForUserGroupMembershipMapping(t *testing.T) {
 		require.Contains(t, groups, authenticationcallouts.UserGroupIDSuperAdmin)
 	})
 
+	t.Run("read-only", func(t *testing.T) {
+		mock.returnSearchValue = &ldap.SearchResult{
+			Entries: []*ldap.Entry{
+				{
+					Attributes: []*ldap.EntryAttribute{
+						{
+							Name:   "groupName",
+							Values: []string{"read-only"},
+						},
+					},
+				},
+			},
+		}
+
+		// Act
+		groups, isAllowed, err := controller.SearchForUserGroupMembership("foo")
+
+		// Assert
+		require.NoError(t, err)
+		require.False(t, isAllowed)
+		require.Len(t, groups, 1)
+		require.Contains(t, groups, authenticationcallouts.UserGroupIDReadOnly)
+	})
+
 	t.Run("admin and super-admin", func(t *testing.T) {
 		mock.returnSearchValue = &ldap.SearchResult{
 			Entries: []*ldap.Entry{
